from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Power_Protection = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'CDNBS08-SLVU2.8-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDNBS08-SLVU2.8-4'}), 'ref_prefix':'D', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'ESD protection suppression transient', 'description':'', 'datasheet':'https://www.bourns.com/pdfs/CDNBS08-SLVU28-4.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nCDNBS08-SLVU2.8-4\n\nESD protection suppression transient', 'pins':[
            Pin(num='1',name='TVS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TVS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TVS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TVS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='TVS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='TVS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='TVS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='TVS2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CM1213A-01SO', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CM1213A-01SO'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'ESD Protection diodes transient suppressor', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/CM1213A-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nCM1213A-01SO\n\nESD Protection diodes transient suppressor', 'pins':[
            Pin(num='1',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CM1624', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CM1624'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:OnSemi_UDFN-16-1EP_1.35x3.3mm_P0.4mm_EP0.4x2.8mm'], 'footprint':'Package_DFN_QFN:OnSemi_UDFN-16-1EP_1.35x3.3mm_P0.4mm_EP0.4x2.8mm', 'keywords':'microsd protection', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/cm1624-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nCM1624\n\nmicrosd protection', 'pins':[
            Pin(num='1',name='SDData1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Data3',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CMD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='ESD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='CLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Data0',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Data1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SDData0',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SDCLK',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='ESD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='ESD3',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='SDCMD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SDData3',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='SDData2',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Data2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'D3V3XA4B10LP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'D3V3XA4B10LP'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Diodes_UDFN-10_1.0x2.5mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Diodes_UDFN-10_1.0x2.5mm_P0.5mm', 'keywords':'ESD protection TVS', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/D3V3XA4B10LP.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nD3V3XA4B10LP\n\nESD protection TVS', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='7',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.FREE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ECMF02-2AMX6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECMF02-2AMX6'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:ST_UQFN-6L_1.5x1.7mm_P0.5mm'], 'footprint':'Package_DFN_QFN:ST_UQFN-6L_1.5x1.7mm_P0.5mm', 'keywords':'Common Mode ESD', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/ecmf02-2amx6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nECMF02-2AMX6\n\nCommon Mode ESD', 'pins':[
            Pin(num='1',name='D+_in',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-_in',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='5',name='D-_out',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D+_out',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EMI2121MTTAG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EMI2121MTTAG'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WDFN-8-1EP_2x2.2mm_P0.5mm_EP0.80x0.54'], 'footprint':'Package_DFN_QFN:WDFN-8-1EP_2x2.2mm_P0.5mm_EP0.80x0.54', 'keywords':'Common Mode ESD', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/EMI2121MT-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nEMI2121MTTAG\n\nCommon Mode ESD', 'pins':[
            Pin(num='1',name='In_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='In_1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='Out_1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EMI8132', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EMI8132'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:OnSemi_XDFN-10_1.35x2.2mm_P0.4mm'], 'footprint':'Package_DFN_QFN:OnSemi_XDFN-10_1.35x2.2mm_P0.4mm', 'keywords':'Common Mode ESD', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/emi8132-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nEMI8132\n\nCommon Mode ESD', 'pins':[
            Pin(num='1',name='In_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='In_1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='In_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='In_1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Out_1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESD224DQA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESD224DQA'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Diodes_UDFN-10_1.0x2.5mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Diodes_UDFN-10_1.0x2.5mm_P0.5mm', 'keywords':'ESD protection TVS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/esd224.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESD224DQA\n\nESD protection TVS', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDA6V1-5SC6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDA6V1-5SC6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD protection suppression transient', 'description':'', 'datasheet':'www.st.com/resource/en/datasheet/esda6v1-5sc6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDA6V1-5SC6\n\nESD protection suppression transient', 'pins':[
            Pin(num='2',name='GND',func=pin_types.PASSIVE),
            Pin(num='1',name='IO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IO5',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDA6V1BC6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDA6V1BC6'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD protection suppression transient', 'description':'', 'datasheet':'http://www.st.com/content/ccc/resource/technical/document/datasheet/21/07/21/e3/a8/df/42/a2/CD00001906.pdf/files/CD00001906.pdf/jcr:content/translations/en.CD00001906.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDA6V1BC6\n\nESD protection suppression transient', 'pins':[
            Pin(num='2',name='COM',func=pin_types.PASSIVE),
            Pin(num='1',name='TVS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TVS2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='TVS3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='TVS4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP3319CX6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP3319CX6'}), 'ref_prefix':'U', 'fplist':['Package_CSP:WLCSP-6_1.4x1.0mm_P0.4mm'], 'footprint':'Package_CSP:WLCSP-6_1.4x1.0mm_P0.4mm', 'keywords':'common mode filter ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP3319CX6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP3319CX6\n\ncommon mode filter ESD protection', 'pins':[
            Pin(num='A1',name='D+_OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='D+_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='D-_OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='B2',name='D-_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='ID',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4234CZ6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4234CZ6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SC-74-6_1.55x2.9mm_P0.95mm'], 'footprint':'Package_TO_SOT_SMD:SC-74-6_1.55x2.9mm_P0.95mm', 'keywords':'USB ESD protection ', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4234CZ6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4234CZ6\n\nUSB ESD protection ', 'pins':[
            Pin(num='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VP',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4252CZ12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4252CZ12'}), 'ref_prefix':'U', 'fplist':['Package_SON:Nexperia_HUSON-12_USON-12-1EP_1.35x2.5mm_P0.4mm_EP0.4x2mm'], 'footprint':'Package_SON:Nexperia_HUSON-12_USON-12-1EP_1.35x2.5mm_P0.4mm_EP0.4x2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4252CZ12\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CH3',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CH2',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CH3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CH4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CH5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CH6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CH6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CH5',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CH4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4252CZ16', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4252CZ16'}), 'ref_prefix':'U', 'fplist':['Package_SON:Nexperia_HUSON-16_USON-16-1EP_1.35x3.3mm_P0.4mm_EP0.4x2.8mm'], 'footprint':'Package_SON:Nexperia_HUSON-16_USON-16-1EP_1.35x3.3mm_P0.4mm_EP0.4x2.8mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4252CZ16\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='CH7',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='CH6',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CH5',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='CH4',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='CH3',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='CH2',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='CH2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CH3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CH4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CH5',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CH6',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CH7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CH8',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CH8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4252CZ8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4252CZ8'}), 'ref_prefix':'U', 'fplist':['Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm'], 'footprint':'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4252CZ8\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CH2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='CH3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CH4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='CH4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CH3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CH2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='CH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP349MN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP349MN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'keywords':'overvoltage protection', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp349-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP349MN\n\novervoltage protection', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP361MU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP361MU'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'overvoltage protection USB', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp361-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP361MU\n\novervoltage protection USB', 'pins':[
            Pin(num='1',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP361SN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP361SN'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-5_1.65x3.05mm_P0.95mm'], 'footprint':'Package_SO:TSOP-5_1.65x3.05mm_P0.95mm', 'keywords':'overvoltage protection USB', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp361-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP361SN\n\novervoltage protection USB', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NUF4401MN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NUF4401MN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NUF4401MN-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNUF4401MN\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NUP2105L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NUP2105L'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'can esd protection suppression transient', 'description':'', 'datasheet':'https://www.onsemi.com/pub_link/Collateral/NUP2105L-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNUP2105L\n\ncan esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NUP2202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NUP2202'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'ESD Protection diodes  transient suppressor', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/nup2202w1-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNUP2202\n\nESD Protection diodes  transient suppressor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NUP4202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NUP4202'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'ESD Protection diodes  transient suppressor', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/NUP4202W1-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNUP4202\n\nESD Protection diodes  transient suppressor', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PCMF3USB3S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PCMF3USB3S'}), 'ref_prefix':'U', 'fplist':['Package_CSP:Nexperia_WLCSP-15_6-3-6_2.37x1.17mm_Layout6x3_P0.4mm'], 'footprint':'Package_CSP:Nexperia_WLCSP-15_6-3-6_2.37x1.17mm_Layout6x3_P0.4mm', 'keywords':'Common Mode ESD', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PCMFXUSB3S_SER.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPCMF3USB3S\n\nCommon Mode ESD', 'pins':[
            Pin(num='A1',name='CH1_IN+',func=pin_types.PASSIVE,unit=1),
            Pin(num='A2',name='CH1_IN-',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='GND_CH1',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='CH1_OUT+',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='CH1_OUT-',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='CH2_IN+',func=pin_types.PASSIVE,unit=2),
            Pin(num='A4',name='CH2_IN-',func=pin_types.PASSIVE,unit=2),
            Pin(num='B2',name='GND_CH2',func=pin_types.PWRIN,unit=2),
            Pin(num='C3',name='CH2_OUT+',func=pin_types.PASSIVE,unit=2),
            Pin(num='C4',name='CH2_OUT-',func=pin_types.PASSIVE,unit=2),
            Pin(num='A5',name='CH3_IN+',func=pin_types.PASSIVE,unit=3),
            Pin(num='A6',name='CH3_IN-',func=pin_types.PASSIVE,unit=3),
            Pin(num='B3',name='GND_CH3',func=pin_types.PWRIN,unit=3),
            Pin(num='C5',name='CH3_OUT+',func=pin_types.PASSIVE,unit=3),
            Pin(num='C6',name='CH3_OUT-',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['A2', 'A1', 'C2', 'B1', 'C1']},{'label': 'uB', 'num': 2, 'pin_nums': ['A3', 'C3', 'A4', 'C4', 'B2']},{'label': 'uC', 'num': 3, 'pin_nums': ['A5', 'C5', 'A6', 'C6', 'B3']}] }),
        Part(**{ 'name':'PESD3V3L4UF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD3V3L4UF'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-886'], 'footprint':'Package_TO_SOT_SMD:SOT-886', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL4UF_G_W.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD3V3L4UF\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='K4',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PESD3V3L4UG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD3V3L4UG'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL4UF_G_W.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD3V3L4UG\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']}] }),
        Part(**{ 'name':'PESD3V3L4UW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD3V3L4UW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-665'], 'footprint':'Package_TO_SOT_SMD:SOT-665', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL4UF_G_W.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD3V3L4UW\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']}] }),
        Part(**{ 'name':'PESD3V3L5UF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD3V3L5UF'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-886'], 'footprint':'Package_TO_SOT_SMD:SOT-886', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL5UF_V_Y.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD3V3L5UF\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PESD3V3L5UV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD3V3L5UV'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-666'], 'footprint':'Package_TO_SOT_SMD:SOT-666', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL5UF_V_Y.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD3V3L5UV\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PESD3V3L5UY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD3V3L5UY'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL5UF_V_Y.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD3V3L5UY\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PRTR5V0U2X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PRTR5V0U2X'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'ESD protection diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PRTR5V0U2X.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPRTR5V0U2X\n\nESD protection diode', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RCLAMP0502B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RCLAMP0502B'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-416'], 'footprint':'Package_TO_SOT_SMD:SOT-416', 'keywords':'tvs unidirectional', 'description':'', 'datasheet':'https://www.semtech.com/products/circuit-protection/low-capacitance/rclamp0502b', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nRCLAMP0502B\n\ntvs unidirectional', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RCLAMP3328P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RCLAMP3328P'}), 'ref_prefix':'D', 'fplist':['Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm'], 'footprint':'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://media.digikey.com/pdf/Data%20Sheets/Semtech%20PDFs/RCLAMP3328P.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nRCLAMP3328P\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65220', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65220'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'USB suppressor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65220.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSN65220\n\nUSB suppressor', 'pins':[
            Pin(num='1',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='A',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN75240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN75240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'USB suppressor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65220.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSN75240\n\nUSB suppressor', 'pins':[
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='4',name='D',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '7', '5', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3', '1', '4']}] }),
        Part(**{ 'name':'SP0502BAHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0502BAHT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0502BAHT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SP0502BAJT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0502BAJT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-323_SC-70'], 'footprint':'Package_TO_SOT_SMD:SOT-323_SC-70', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0502BAJT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SP0503BAHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0503BAHT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-143'], 'footprint':'Package_TO_SOT_SMD:SOT-143', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0503BAHT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='1',name='A',func=pin_types.PASSIVE),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SP0504BAHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0504BAHT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0504BAHT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SP0504BAJT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0504BAJT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0504BAJT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SP0505BAHT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0505BAHT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0505BAHT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SP0505BAJT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP0505BAJT'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'http://www.littelfuse.com/~/media/files/littelfuse/technical%20resources/documents/data%20sheets/sp05xxba.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP0505BAJT\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SRV05-4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SRV05-4'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD protection diodes', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/SRV05-4-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSRV05-4\n\nESD protection diodes', 'pins':[
            Pin(num='1',name='IO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VP',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IO4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-025-050-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-025-050-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-025-050-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD1E05U06DPY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD1E05U06DPY'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_DPY0002A_0.6x1mm_P0.65mm'], 'footprint':'Package_SON:Texas_DPY0002A_0.6x1mm_P0.65mm', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpd1e05u06.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD1E05U06DPY\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='I/O',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD2E2U06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD2E2U06'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-543'], 'footprint':'Package_TO_SOT_SMD:SOT-543', 'keywords':'ESD-Protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd2e2u06.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD2E2U06\n\nESD-Protection', 'pins':[
            Pin(num='1',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD2EUSB30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD2EUSB30'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Texas_DRT-3'], 'footprint':'Package_TO_SOT_SMD:Texas_DRT-3', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd2eusb30a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD2EUSB30\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='D+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD2S017', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD2S017'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd2s017.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD2S017\n\nESD protection', 'pins':[
            Pin(num='1',name='CH1Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='CH1In',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CH2Int',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='CH2Out',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD3E001DRLR', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD3E001DRLR'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-553'], 'footprint':'Package_TO_SOT_SMD:SOT-553', 'keywords':'ESD-Protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd3e001.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD3E001DRLR\n\nESD-Protection', 'pins':[
            Pin(num='1',name='IO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD3F303DPV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD3F303DPV'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_R-PUSON-N8_USON-8-1EP_1.6x2.1mm_P0.5mm_EP0.4x1.7mm'], 'footprint':'Package_SON:Texas_R-PUSON-N8_USON-8-1EP_1.6x2.1mm_P0.5mm_EP0.4x1.7mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/tpd3f303', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD3F303DPV\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='DATA1_OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CLK_OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='DATA2_OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DATA2_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='CLK_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DATA1_IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD3S014', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD3S014'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD-Protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd3s014.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD3S014\n\nESD-Protection', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD4E02B04DQA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD4E02B04DQA'}), 'ref_prefix':'U', 'fplist':['Package_SON:USON-10_2.5x1.0mm_P0.5mm'], 'footprint':'Package_SON:USON-10_2.5x1.0mm_P0.5mm', 'keywords':'ESD protection USB HDMI', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd4e02b04.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD4E02B04DQA\n\nESD protection USB HDMI', 'pins':[
            Pin(num='3',name='G',func=pin_types.PASSIVE),
            Pin(num='1',name='IO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='IO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IO4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='7',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='8',name='G',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.FREE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD4EUSB30', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD4EUSB30'}), 'ref_prefix':'U', 'fplist':['Package_SON:USON-10_2.5x1.0mm_P0.5mm'], 'footprint':'Package_SON:USON-10_2.5x1.0mm_P0.5mm', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd2eusb30a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD4EUSB30\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='7',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.FREE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD4S014', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD4S014'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_S-PWSON-N10'], 'footprint':'Package_SON:Texas_S-PWSON-N10', 'keywords':'USB  Port Protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd4s014.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD4S014\n\nUSB  Port Protection', 'pins':[
            Pin(num='1',name='VBUSOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='10',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='PAD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VBUSOUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{ACK}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='ID',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VBUS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD4S1394', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD4S1394'}), 'ref_prefix':'U', 'fplist':['Package_SON:X2SON-8_1.4x1mm_P0.35mm'], 'footprint':'Package_SON:X2SON-8_1.4x1mm_P0.35mm', 'keywords':'firewire ESD clamp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd4s1394.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD4S1394\n\nfirewire ESD clamp', 'pins':[
            Pin(num='1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VCLMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='FWPWR_EN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='D1-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD6E05U06RVZ', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD6E05U06RVZ'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_R-PUSON-N14'], 'footprint':'Package_SON:Texas_R-PUSON-N14', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpd1e05u06.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD6E05U06RVZ\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='3',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='4',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='7',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='8',name='D3-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='D3+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD6F003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD6F003'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_R-PWSON-N12_EP0.4x2mm'], 'footprint':'Package_SON:Texas_R-PWSON-N12_EP0.4x2mm', 'keywords':'EMI, ESD protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd6f003.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD6F003\n\nEMI, ESD protection', 'pins':[
            Pin(num='1',name='Ch1_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Ch3_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Ch2_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Ch1_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ch2_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Ch3_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Ch4_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Ch5_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Ch6_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Ch6_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Ch5_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Ch4_Out',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD6S300A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD6S300A'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm_ThermalVias'], 'footprint':'Package_DFN_QFN:WQFN-20-1EP_3x3mm_P0.4mm_EP1.7x1.7mm_ThermalVias', 'keywords':'USB-C ESD', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpd6s300a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD6S300A\n\nUSB-C ESD', 'pins':[
            Pin(num='1',name='C_SBU1',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VPWR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='SBU2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='SBU1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='D2',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C_SBU2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='D1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='VBIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='C_CC1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='C_CC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RPD_G2',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RPD_G1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{FLT}',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD8F003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD8F003'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-16_3.3x1.35_P0.4mm'], 'footprint':'Package_SON:WSON-16_3.3x1.35_P0.4mm', 'keywords':'EMI, ESD protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd6f003.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD8F003\n\nEMI, ESD protection', 'pins':[
            Pin(num='1',name='Ch1_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Ch7_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='Ch6_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='Ch5_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Ch4_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='Ch3_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Ch2_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='Ch1_Out',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Ch2_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='Ch3_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='Ch4_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='Ch5_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Ch6_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Ch7_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='Ch8_In',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Ch8_Out',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TVS0500DRV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TVS0500DRV'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'EMI, ESD, TVS protection transient', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tvs0500.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTVS0500DRV\n\nEMI, ESD, TVS protection transient', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USB6B1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USB6B1'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'ESD USB', 'description':'', 'datasheet':'http://www.st.com/content/ccc/resource/technical/document/datasheet/3e/ec/b2/54/b2/76/47/90/CD00001361.pdf/files/CD00001361.pdf/jcr:content/translations/en.CD00001361.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nUSB6B1\n\nESD USB', 'pins':[
            Pin(num='1',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USBLC6-2P6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USBLC6-2P6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-666'], 'footprint':'Package_TO_SOT_SMD:SOT-666', 'keywords':'usb ethernet video', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/usblc6-2.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nUSBLC6-2P6\n\nusb ethernet video', 'pins':[
            Pin(num='1',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I/O1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USBLC6-4SC6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USBLC6-4SC6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'usb ethernet sim card video', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/usblc6-4.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nUSBLC6-4SC6\n\nusb ethernet sim card video', 'pins':[
            Pin(num='1',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I/O3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I/O4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WE-TVS-82400102', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WE-TVS-82400102'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD Protection TVS High-speed USB', 'description':'', 'datasheet':'https://www.we-online.com/components/products/datasheet/82400102.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nWE-TVS-82400102\n\nESD Protection TVS High-speed USB', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN056V130A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN056V130A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN056V130A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CDSOT236-0504C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CDSOT236-0504C'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD protection diodes', 'description':'', 'datasheet':'https://www.bourns.com/docs/product-datasheets/cdsot236-0504c.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nCDSOT236-0504C\n\nESD protection diodes', 'pins':[
            Pin(num='1',name='IO1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VN',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IO2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IO3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VP',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IO4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'DT1240A-08LP3810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'DT1240A-08LP3810'}), 'ref_prefix':'D', 'fplist':['Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm'], 'footprint':'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/DT1240A-08LP3810.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nDT1240A-08LP3810\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ECMF04-4HSWM10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ECMF04-4HSWM10'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:OnSemi_XDFN-10_1.35x2.2mm_P0.4mm', 'Package_DFN_QFN:UDFN-10_1.35x2.6mm_P0.5mm'], 'footprint':'Package_DFN_QFN:OnSemi_XDFN-10_1.35x2.2mm_P0.4mm', 'keywords':'Common Mode ESD', 'description':'', 'datasheet':'https://www.st.com/content/ccc/resource/technical/document/datasheet/fa/13/38/f2/70/5b/46/46/DM00109760.pdf/files/DM00109760.pdf/jcr:content/translations/en.DM00109760.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nECMF04-4HSWM10\n\nCommon Mode ESD', 'pins':[
            Pin(num='1',name='In_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='In_1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='In_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='In_1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='Out_1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='Out_1+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDA14V2SC5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDA14V2SC5'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'esd protection suppression transient', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/esda5v3sc6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDA14V2SC5\n\nesd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDA5V3L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDA5V3L'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23-3'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/esdal.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDA5V3L\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDA5V3SC5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDA5V3SC5'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/esda5v3sc6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDA5V3SC5\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDA6V1SC5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDA6V1SC5'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/esda5v3sc6.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDA6V1SC5\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='2',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESDLC5V0PB8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESDLC5V0PB8'}), 'ref_prefix':'D', 'fplist':['Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm'], 'footprint':'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://www.mccsemi.com/pdf/Products/ESDLC5V0PB8(DFN3810-9)-A.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nESDLC5V0PB8\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4251CZ8-4-TTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4251CZ8-4-TTL'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4251CZ8-4-TTL\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4252CZ8-4-TTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4252CZ8-4-TTL'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4252CZ8-4-TTL\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4253CZ8-4-TTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4253CZ8-4-TTL'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4253CZ8-4-TTL\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IP4254CZ8-4-TTL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IP4254CZ8-4-TTL'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm', 'Package_SON:Nexperia_HUSON-8_USON-8-1EP_1.35x1.7mm_P0.4mm_EP0.4x1.2mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_2x2mm_P0.5mm_EP0.6x1.2mm', 'keywords':'EMI ESD protection', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/IP4251_52_53_54-TTL.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nIP4254CZ8-4-TTL\n\nEMI ESD protection', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN4',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='OUT3',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='OUT2',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='OUT1',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP349MNAE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP349MNAE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'keywords':'overvoltage protection', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp349-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP349MNAE\n\novervoltage protection', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP349MNAM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP349MNAM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'keywords':'overvoltage protection', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp349-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP349MNAM\n\novervoltage protection', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP349MNBG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP349MNBG'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'keywords':'overvoltage protection', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp349-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP349MNBG\n\novervoltage protection', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCP349MNBK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCP349MNBK'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_2x1.6mm_P0.5mm_EP1.15x1.3mm', 'keywords':'overvoltage protection', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/ncp349-d.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nNCP349MNBK\n\novervoltage protection', 'pins':[
            Pin(num='1',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{FLAG}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{EN}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PESD5V0L4UF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD5V0L4UF'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-886', 'Package_TO_SOT_SMD:SOT-886'], 'footprint':'Package_TO_SOT_SMD:SOT-886', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL4UF_G_W.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD5V0L4UF\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='K4',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PESD5V0L4UG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD5V0L4UG'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL4UF_G_W.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD5V0L4UG\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']}] }),
        Part(**{ 'name':'PESD5V0L4UW', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD5V0L4UW'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-665', 'Package_TO_SOT_SMD:SOT-665'], 'footprint':'Package_TO_SOT_SMD:SOT-665', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL4UF_G_W.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD5V0L4UW\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']}] }),
        Part(**{ 'name':'PESD5V0L5UF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD5V0L5UF'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-886', 'Package_TO_SOT_SMD:SOT-886'], 'footprint':'Package_TO_SOT_SMD:SOT-886', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL5UF_V_Y.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD5V0L5UF\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PESD5V0L5UV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD5V0L5UV'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-666', 'Package_TO_SOT_SMD:SOT-666'], 'footprint':'Package_TO_SOT_SMD:SOT-666', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL5UF_V_Y.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD5V0L5UV\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'PESD5V0L5UY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PESD5V0L5UY'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-363_SC-70-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'Package_TO_SOT_SMD:SOT-363_SC-70-6', 'keywords':'diode', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/PESDXL5UF_V_Y.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nPESD5V0L5UY\n\ndiode', 'pins':[
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='K2',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=4),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4']},{'label': 'uD', 'num': 4, 'pin_nums': ['5']},{'label': 'uE', 'num': 5, 'pin_nums': ['6']}] }),
        Part(**{ 'name':'RCLAMP0502BA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RCLAMP0502BA'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-416', 'Package_TO_SOT_SMD:SOT-416'], 'footprint':'Package_TO_SOT_SMD:SOT-416', 'keywords':'tvs unidirectional', 'description':'', 'datasheet':'https://www.semtech.com/products/circuit-protection/low-capacitance/rclamp0502ba', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nRCLAMP0502BA\n\ntvs unidirectional', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RCLAMP0582B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RCLAMP0582B'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-416', 'Package_TO_SOT_SMD:SOT-416', 'Package_TO_SOT_SMD:SOT-416'], 'footprint':'Package_TO_SOT_SMD:SOT-416', 'keywords':'tvs unidirectional', 'description':'', 'datasheet':'https://www.semtech.com/products/circuit-protection/low-capacitance/rclamp0582b', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nRCLAMP0582B\n\ntvs unidirectional', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN65240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN65240'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'USB suppressor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn65220.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSN65240\n\nUSB suppressor', 'pins':[
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='B',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='A',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='4',name='D',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '8', '5', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3', '4', '1']}] }),
        Part(**{ 'name':'SP7538P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SP7538P'}), 'ref_prefix':'D', 'fplist':['Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm'], 'footprint':'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://www.littelfuse.com/~/media/electronics/datasheets/tvs_diode_arrays/littelfuse_tvs_diode_array_sp7538p_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSP7538P\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SZNUP2105L', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SZNUP2105L'}), 'ref_prefix':'D', 'fplist':['Package_TO_SOT_SMD:SOT-23', 'Package_TO_SOT_SMD:SOT-23'], 'footprint':'Package_TO_SOT_SMD:SOT-23', 'keywords':'can esd protection suppression transient automotive', 'description':'', 'datasheet':'https://www.onsemi.com/pub_link/Collateral/NUP2105L-D.PDF', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nSZNUP2105L\n\ncan esd protection suppression transient automotive', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-025-100-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-025-100-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-025-100-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-025-200-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-025-200-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-025-200-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-025-300-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-025-300-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-025-300-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-025-500-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-025-500-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-025-500-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-040-050-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-040-050-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-040-050-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-040-100-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-040-100-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-040-100-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-040-200-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-040-200-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-040-200-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-040-300-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-040-300-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-040-300-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-040-500-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-040-500-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-040-500-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-050-050-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-050-050-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-050-050-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-050-100-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-050-100-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-050-100-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-050-200-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-050-200-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-050-200-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-050-300-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-050-300-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-050-300-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-050-500-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-050-500-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-050-500-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-065-050-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-065-050-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-065-050-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-065-100-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-065-100-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-065-100-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-065-200-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-065-200-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-065-200-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-065-300-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-065-300-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-065-300-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-065-500-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-065-500-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-065-500-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-085-050-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-085-050-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-085-050-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-085-100-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-085-100-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-085-100-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-085-200-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-085-200-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-085-200-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-085-300-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-085-300-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-085-300-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBU-CA-085-500-WH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBU-CA-085-500-WH'}), 'ref_prefix':'F', 'fplist':['Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA', 'Fuse:Fuse_Bourns_TBU-CA'], 'footprint':'Fuse:Fuse_Bourns_TBU-CA', 'keywords':'high speed bidirectional protection', 'description':'', 'datasheet':'https://www.bourns.com/data/global/pdfs/TBU-CA.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTBU-CA-085-500-WH\n\nhigh speed bidirectional protection', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD1E05U06DYA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD1E05U06DYA'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_DPY0002A_0.6x1mm_P0.65mm', 'Diode_SMD:D_SOD-523'], 'footprint':'Package_SON:Texas_DPY0002A_0.6x1mm_P0.65mm', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpd1e05u06.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD1E05U06DYA\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='I/O',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD2EUSB30A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD2EUSB30A'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:Texas_DRT-3', 'Package_TO_SOT_SMD:Texas_DRT-3'], 'footprint':'Package_TO_SOT_SMD:Texas_DRT-3', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd2eusb30a.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD2EUSB30A\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='D+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='D-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD3S044', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD3S044'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD-Protection', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpd3s014.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD3S044\n\nESD-Protection', 'pins':[
            Pin(num='1',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='OUT',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='D2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPD4E05U06DQA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPD4E05U06DQA'}), 'ref_prefix':'U', 'fplist':['Package_SON:USON-10_2.5x1.0mm_P0.5mm', 'Package_SON:USON-10_2.5x1.0mm_P0.5mm'], 'footprint':'Package_SON:USON-10_2.5x1.0mm_P0.5mm', 'keywords':'ESD protection USB 3.0', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpd4e05u06.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTPD4E05U06DQA\n\nESD protection USB 3.0', 'pins':[
            Pin(num='1',name='D1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='D1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='D2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='D2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='7',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.FREE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TVS1400DRV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TVS1400DRV'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'EMI, ESD, TVS protection transient', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tvs1400.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTVS1400DRV\n\nEMI, ESD, TVS protection transient', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TVS1800DRV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TVS1800DRV'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'EMI, ESD, TVS protection transient', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tvs1800.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTVS1800DRV\n\nEMI, ESD, TVS protection transient', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TVS2200DRV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TVS2200DRV'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'EMI, ESD, TVS protection transient', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tvs2200.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTVS2200DRV\n\nEMI, ESD, TVS protection transient', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TVS2700DRV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TVS2700DRV'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'EMI, ESD, TVS protection transient', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tvs2700.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTVS2700DRV\n\nEMI, ESD, TVS protection transient', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TVS3300DRV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TVS3300DRV'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm'], 'footprint':'Package_SON:WSON-6-1EP_2x2mm_P0.65mm_EP1x1.6mm', 'keywords':'EMI, ESD, TVS protection transient', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tvs3300.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nTVS3300DRV\n\nEMI, ESD, TVS protection transient', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='IN',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USBLC6-2SC6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USBLC6-2SC6'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-666', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-666', 'keywords':'usb ethernet video', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/usblc6-2.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nUSBLC6-2SC6\n\nusb ethernet video', 'pins':[
            Pin(num='1',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I/O1',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WE-TVS-824014881', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WE-TVS-824014881'}), 'ref_prefix':'D', 'fplist':['Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm'], 'footprint':'Package_DFN_QFN:UDFN-9_1.0x3.8mm_P0.5mm', 'keywords':'usb esd protection suppression transient', 'description':'', 'datasheet':'https://eu.mouser.com/datasheet/2/445/824014881-1724976.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nWE-TVS-824014881\n\nusb esd protection suppression transient', 'pins':[
            Pin(num='3',name='A',func=pin_types.PASSIVE),
            Pin(num='1',name='K1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='K2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='K3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='K4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='K5',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='K6',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='K7',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='K8',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'WE-TVS-824015043', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'WE-TVS-824015043'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'ESD Protection TVS High-speed USB', 'description':'', 'datasheet':'https://www.we-online.com/components/products/datasheet/824015043.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nWE-TVS-824015043\n\nESD Protection TVS High-speed USB', 'pins':[
            Pin(num='1',name='I/O1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='I/O2',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='I/O3',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VBUS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='I/O4',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN056V075A48LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN056V075A48LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN056V075A48LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN056V115A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN056V115A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN056V115A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN056V230A16LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN056V230A16LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN056V230A16LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN059V130A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN059V130A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN059V130A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN065V130A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN065V130A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN065V130A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN065V230A16LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN065V230A16LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN065V230A16LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN098V130A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN098V130A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN098V130A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN098V230A16LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN098V230A16LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN098V230A16LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN132V075A48LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN132V075A48LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN132V075A48LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN132V130A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN132V130A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN132V130A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN132V230A16LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN132V230A16LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN132V230A16LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZEN164V130A24LS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZEN164V130A24LS'}), 'ref_prefix':'D', 'fplist':['Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS', 'Diode_SMD:Littelfuse_PolyZen-LS'], 'footprint':'Diode_SMD:Littelfuse_PolyZen-LS', 'keywords':'Polymer zener', 'description':'', 'datasheet':'http://m.littelfuse.com/~/media/electronics/datasheets/polyzen_devices/littelfuse_polyzen_standard_polyzen_catalog_datasheet.pdf.pdf', 'search_text':'/usr/share/kicad/symbols/Power_Protection.kicad_sym\nZEN164V130A24LS\n\nPolymer zener', 'pins':[
            Pin(num='1',name='VIN',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VOUT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])